# Schedwi
# Copyright (C) 2011, 2012 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy.schema import Column, ForeignKey
from sqlalchemy.types import Integer, String

from base import Base, convert2unicode


class job_file_out(Base):
    __tablename__ = 'job_file_out'

    job_id = Column(Integer, ForeignKey('job_main.id'), primary_key=True)
    file_out = Column(String(255))

    def __init__(self, file_out):
        self.file_out = convert2unicode(file_out)

    def copy(self):
        return job_file_out(self.file_out)
